..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

===============
 Invenio Theme
===============

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-theme.svg
        :target: https://github.com/inveniosoftware/invenio-theme/blob/master/LICENSE

.. image:: https://github.com/inveniosoftware/invenio-theme/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-theme/actions

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-theme.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-theme

.. image:: https://img.shields.io/pypi/v/invenio-theme.svg
        :target: https://pypi.org/pypi/invenio-theme


Invenio standard theme.

Features:

* Default templates for displaying the page cover, settings, admin settings, breadcrumbs.

* Different templates for error codes.

* Jinja2 macro for displaying flashed messages.

Further documentation available at https://invenio-theme.readthedocs.io/
